@@ -26,10 +26,8 @@ set_class <- function(x, class) {
   x
 }
 
-#' @export
 .esr <- function(x, na_rm) {
   stopifnot(is.matrix(x))
-  niters <- niters(x)
   x <- apply(x, 1L, .esr_numeric, na_rm = na_rm)
   x <- unlist(x)
   round(mean(x), 3)
@@ -41,10 +39,10 @@ set_class <- function(x, class) {
   if (!na_rm && any(is.na(x))) {
     return(NA_real_)
   }
-  x <- stats::acf(x,
-    lag.max = length(x) - 1, na.action = na.pass,
-    plot = FALSE
-  )$acf[, , 1]
+  if (length(unique(x)) == 1) {
+    return(1)
+  }
+  x <- stats::acf(x, lag.max = length(x) - 1, na.action = na.pass, plot = FALSE)$acf[, , 1]
 
   if (is.nan(x[1])) {
     return(1)
@@ -56,7 +54,6 @@ set_class <- function(x, class) {
   1 / (1 + 2 * x)
 }
 
-#' @export
 .estimates <- function(object, fun = median, ...) {
   stopifnot(is.matrix(object))
   nrow <- nrow(object)
@@ -66,7 +63,6 @@ set_class <- function(x, class) {
   object
 }
 
-#' @export
 .rhat <- function(x, na_rm) {
   stopifnot(is.matrix(x))
 
