@@ -6,7 +6,15 @@ test_that(".esr_numeric", {
   vector[1] <- NA
   expect_true(is.na(.esr_numeric(vector, na_rm = FALSE)))
   expect_identical(.esr_numeric(vector, na_rm = TRUE), 1)
+  expect_equal(.esr_numeric(1:2, na_rm = FALSE), 1)
+  expect_equal(.esr_numeric(1:3, na_rm = FALSE), 1)
+  expect_equal(.esr_numeric(c(10, 20, 30), na_rm = FALSE), 1)
+  expect_equal(.esr_numeric(1:4, na_rm = FALSE), 2 / 3)
+  expect_equal(.esr_numeric(1:5, na_rm = FALSE), 0.555555555555556)
   expect_equal(.esr_numeric(1:10, na_rm = FALSE), 0.283993115318416)
+  set.seed(42)
+  x <- rnorm(10)
+  expect_equal(.esr_numeric(x, na_rm = FALSE), 1)
 })
 
 test_that("esr.matrix", {
@@ -75,6 +83,22 @@ test_that("esr.mcmcr NA", {
   expect_identical(esr(x, by = "parameter", na_rm = TRUE), list(alpha = 0.011, beta = 0.05, sigma = 0.472))
 })
 
+test_that("esr.mcmcr constant", {
+  x <- mcmcr::mcmcr_example
+  x$sigma[, , 1] <- 0
+
+  expect_identical(esr(x$sigma), 1)
+
+  expect_identical(esr(x), 0.011)
+})
+
 test_that("esr.mcmcrs", {
   expect_identical(esr(mcmcrs(mcmcr_example, mcmcr_example)), list(mcmcr1 = 0.011, mcmcr2 = 0.011))
 })
+
+test_that("esr.mcmcarray constant", {
+  x <- structure(rep(-0.75377180237638, 300), dim = c(3L, 100L, 1L), class = "mcmcarray")
+  expect_identical(esr(x), 1)
+  x <- structure(rep(-0.75377180237638, 30), dim = c(3L, 10L, 1L), class = "mcmcarray")
+  expect_identical(esr(x), 1)
+})
