@@ -20,10 +20,23 @@ test_that("ess.mcmcr as df", {
       "tbl", "data.frame"
     ))
   )
-  expect_snapshot_data(ess(mcmcr_example, as_df = TRUE, by = "parameter"),
-                       "ess")
+  expect_snapshot_data(
+    ess(mcmcr_example, as_df = TRUE, by = "parameter"),
+    "ess"
+  )
 })
 
-test_that("ess.mcmcrs", {
-  expect_identical(ess(mcmcrs(mcmcr_example), by = "parameter")[[1]], list(alpha = 9L, beta = 40L, sigma = 378L))
+test_that("ess.mcmcr constant", {
+  x <- mcmcr::mcmcr_example
+  x$sigma[, , 1] <- 0
+
+  expect_identical(ess(x$sigma), 800L)
+  expect_identical(ess(x), 9L)
+})
+
+test_that("ess.mcmcarray constant", {
+  x <- structure(rep(-0.75377180237638, 300), dim = c(3L, 100L, 1L), class = "mcmcarray")
+  expect_identical(ess(x), 300L)
+  x <- structure(rep(-0.75377180237638, 30), dim = c(3L, 10L, 1L), class = "mcmcarray")
+  expect_identical(ess(x), 30L)
 })
