@@ -1,5 +1,5 @@
 test_that("parameters.mcmcr", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
+  rlang::local_options(lifecycle_verbosity = "quiet")
   lifecycle::expect_deprecated(parameters(mcmcr::mcmcr_example))
   expect_identical(parameters(mcmcr::mcmcr_example), c("alpha", "beta", "sigma"))
   expect_identical(parameters(mcmcr::mcmcr_example, scalar = TRUE), c("sigma"))
@@ -9,7 +9,7 @@ test_that("parameters.mcmcr", {
 })
 
 test_that("parameters.mcmcrs", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
+  rlang::local_options(lifecycle_verbosity = "quiet")
   mcmcrs <- mcmcrs(mcmcr::mcmcr_example, mcmcr::mcmcr_example)
   lifecycle::expect_deprecated(parameters(mcmcrs))
   expect_identical(parameters(mcmcrs), c("alpha", "beta", "sigma"))
