@@ -1,5 +1,3 @@
-context("print")
-
 test_that("print.mcmcarray", {
   expect_output(print(mcmcr_example[[1]]))
 })
@@ -9,5 +7,5 @@ test_that("print.mcmcr", {
 })
 
 test_that("print.mcmcr", {
-  expect_output(print(as.term(mcmcr_example)))
+  expect_output(print(as_term(mcmcr_example)))
 })
